/*
   Client invoquant la methode 'getAster' du web service Skybot3D
   URI: http://vo.imcce.fr/webservices/skybot3d/
   WSDL: http://vo.imcce.fr/webservices/skybot3d/skybot3d.wsdl
*/

#include <string.h>
#include <stdio.h>
#include <getopt.h>

#include "soapH.h"
#include "SkyBoT3dBinding.nsmap"

#include "help.h"

int main(int argc, char *argv[])
{ 
   /* declaration des variables */
   struct soap soap;
   struct ns1__getAsterRequest input;
   struct ns1__getAsterResponse output;

   char *s_options = "he:f:l:m:";
   static struct option long_options[] = {
      {"help",  no_argument,       0, 'h'},
      {"epoch", required_argument, 0, 'e'},
      {"class", required_argument, 0, 'f'},
      {"limit", required_argument, 0, 'l'},
      {"mime",  required_argument, 0, 'm'}
   };
   int c, option_index = 0;

   /* initialisations par defaut des parametres */
   input.epoch = "now";
   input.mime = "json";
   input.class = "";
   input.limit = malloc(sizeof(int));
   *input.limit = 0;

   /* lecture des arguments */
   while ((c = getopt_long(argc, argv, s_options, long_options, &option_index)) != -1)
   {
      switch (c)
      {
      case 'h':
         usage_help(argv[0]);
         exit(EXIT_SUCCESS);
      case 'e':
         input.epoch = optarg;
         break;
      case 'c':
         input.class = optarg;
         break;
      case 'm':
         input.mime = optarg;
         break;
      case 'l':
         *input.limit = atoi(optarg);
         break;
      default:
         usage_help(argv[0]);
         exit(EXIT_SUCCESS);
      }
   }

   /* Instanciation du web service */
   soap_init(&soap);

   /* Definition de l'entete SOAP */
   soap.header = soap_malloc(&soap,sizeof(struct SOAP_ENV__Header));
   struct ns1__clientID *p = malloc(sizeof(*p));
   p->from = "Skybot3D.C-client";
   p->hostip = "";
   soap.header->ns1__clientID = p;
   
   /* Invocation du web service */
   if (soap_call_ns1__getAster(&soap, NULL, NULL, &input, &output) == SOAP_OK)
   {
      printf("Flag      : %d\n", output.result->flag); 
      printf("Ticket    : %jd\n", output.result->ticket); 
      if (output.result->nbast != NULL) {
         printf("NbAst     : %d\n", *output.result->nbast); 
      }
      if (output.result->refdate != NULL) {
         printf("RefDate   : %f\n", *output.result->refdate);
      }
      if (output.result->file != NULL) {
         printf("File name : %s\n", output.result->file); 
      }
      if (output.result->size != NULL) {
         printf("File size : %d bytes\n", *output.result->size); 
      }
   }
   else
   {
      soap_print_fault(&soap, stderr);
   }
   
   free(input.limit);
   free(p);
   
   soap_end(&soap);
   soap_done(&soap);
   
   return EXIT_SUCCESS;
}
